@@ -58,11 +58,12 @@ void __connman_profile_list(DBusMessageIter *iter);
 int __connman_log_init(gboolean detach, gboolean debug);
 void __connman_log_cleanup(void);
 
+void __connman_toggle_debug(void);
 gboolean __connman_debug_enabled(void);
 
 #include <connman/plugin.h>
 
-int __connman_plugin_init(const char *pattern);
+int __connman_plugin_init(const char *pattern, const char *exclude);
 void __connman_plugin_cleanup(void);
 
 #include <connman/security.h>
@@ -100,11 +101,14 @@ void __connman_driver_rescan(struct connman_driver *driver);
 
 #include <connman/element.h>
 
-int __connman_element_init(DBusConnection *conn, const char *device);
+int __connman_element_init(DBusConnection *conn, const char *device,
+							const char *nodevice);
 void __connman_element_start(void);
 void __connman_element_stop(void);
 void __connman_element_cleanup(void);
 
+void __connman_element_initialize(struct connman_element *element);
+
 typedef void (* element_cb_t) (struct connman_element *element,
 							gpointer user_data);
 
@@ -130,6 +134,11 @@ static inline void __connman_element_unlock(struct connman_element *element)
 {
 }
 
+int __connman_element_append_ipv4(struct connman_element *element,
+						DBusMessageIter *dict);
+int __connman_element_set_ipv4(struct connman_element *element,
+				const char *name, DBusMessageIter *value);
+
 int __connman_detect_init(void);
 void __connman_detect_cleanup(void);
 
@@ -161,9 +170,14 @@ void __connman_device_cleanup(void);
 void __connman_device_increase_connections(struct connman_device *device);
 void __connman_device_decrease_connections(struct connman_device *device);
 
+void __connman_device_set_network(struct connman_device *device,
+					struct connman_network *network);
+
+void __connman_device_disconnect(struct connman_device *device);
+
 connman_bool_t __connman_device_has_driver(struct connman_device *device);
 
-int __connman_device_set_flightmode(connman_bool_t flightmode);
+int __connman_device_set_offlinemode(connman_bool_t offlinemode);
 
 #include <connman/network.h>
 
@@ -173,6 +187,8 @@ void __connman_network_cleanup(void);
 void __connman_network_set_device(struct connman_network *network,
 					struct connman_device *device);
 
+int __connman_network_disconnect(struct connman_network *network);
+
 connman_bool_t __connman_network_has_driver(struct connman_network *network);
 
 #include <connman/rtnl.h>
